#[non_exhaustive]enum StringProperty {
Show 14 variants
Age = 16_384,
BidiMirroringGlyph = 16_385,
BidiPairedBracket = 16_397,
CaseFolding = 16_386,
ISOComment = 16_387,
LowercaseMapping = 16_388,
Name = 16_389,
SimpleCaseFolding = 16_390,
SimpleLowercaseMapping = 16_391,
SimpleTitlecaseMapping = 16_392,
SimpleUppercaseMapping = 16_393,
TitlecaseMapping = 16_394,
Unicode1Name = 16_395,
UppercaseMapping = 16_396,
}Expand description
This type can represent any Unicode string property.
This is intended to be used in situations where the exact unicode property needed is only known at runtime, for example in regex engines.
The values are intended to be identical to ICU4C’s UProperty enum
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Age = 16_384
BidiMirroringGlyph = 16_385
BidiPairedBracket = 16_397
CaseFolding = 16_386
ISOComment = 16_387
LowercaseMapping = 16_388
Name = 16_389
SimpleCaseFolding = 16_390
SimpleLowercaseMapping = 16_391
SimpleTitlecaseMapping = 16_392
SimpleUppercaseMapping = 16_393
TitlecaseMapping = 16_394
Unicode1Name = 16_395
UppercaseMapping = 16_396